border_colours: Colour scheme for well borders

border_coloursR Documentation

Colour scheme for well borders

Description

A colour scheme for the borders of wells that contains 4 colours. The colours are meant to mark the status of a well (Fail, Check, OK and Not tested). They do not appear in the protti_colours and viridis_colours schemes, which ensures that borders are visible on every fill colour.

Usage

border_colours

Format

A vector containing 4 colours


ggplate documentation built on Sept. 1, 2026, 5:07 p.m.