data_continuous_1536: Continuous 1536-well plate dataset (A-AF)

data_continuous_1536R Documentation

Continuous 1536-well plate dataset (A-AF)

Description

A dataset containing 1536 positive numeric values randomly generated using a normal distribution (rnorm()). Each value is assigned to a position in a 1536-well plate. The row format uses the A-AF labeling. The Status column marks the wells at the edge of the plate, which are prone to evaporation.

Usage

data_continuous_1536

Format

A data frame with a well, a Value and a Status column.

Randomly generated.


ggplate documentation built on Sept. 1, 2026, 5:07 p.m.