| data_continuous_1536_Aa | R Documentation |
A dataset containing 1536 positive numeric values randomly generated using a normal distribution (rnorm()).
Each value is assigned to a position in a 1536-well plate. The row format uses the Ab-Hd labeling.
The Status column marks the four columns of the plate that were not used.
data_continuous_1536_Aa
A data frame with a well, a Value and a Status column.
Randomly generated.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.