data_continuous_384: Continuous 384-well plate dataset

data_continuous_384R Documentation

Continuous 384-well plate dataset

Description

A dataset containing 384 positive numeric values randomly generated using a normal distribution (rnorm()). Each value is assigned to a position in a 384-well plate. The Status column marks the wells at the edge of the plate, which are prone to evaporation.

Usage

data_continuous_384

Format

A data frame with a Value, a well and a Status column.

Randomly generated.


ggplate documentation built on Sept. 1, 2026, 5:07 p.m.