data_continuous_6: Continuous 6-well plate dataset

data_continuous_6R Documentation

Continuous 6-well plate dataset

Description

A dataset containing 6 positive numeric values randomly generated using a normal distribution (rnorm()). Each value is assigned to a position in a 6-well plate. The Status column marks the well with a very low signal.

Usage

data_continuous_6

Format

A data frame with a Value, a well and a Status column.

Randomly generated.


ggplate documentation built on Sept. 1, 2026, 5:07 p.m.