Skip to contents

A dataset containing 96 positive numeric values randomly generated using a normal distribution (rnorm()). Each value is assigned to a position in a 96-well plate. The Status column marks wells with a low signal.

Usage

data_continuous_96

Format

A data frame with a Value, a well and a Status column.

Randomly generated.