data_discrete_24: Discrete 24-well plate dataset

data_discrete_24R Documentation

Discrete 24-well plate dataset

Description

A dataset containing 12 conditions for an siRNA treatment in a 24-well plate. The siRNA treatment consists of a control (siControl) and 11 siRNAs targeting mRNAs of proteins in the mTORC1 pathway. Each treatment is assigned to a position in a 24-well plate. The Status column marks the knockdowns that did not work as expected.

Usage

data_discrete_24

Format

A data frame with a Condition, a well and a Status column.

Theoretically possible siRNA treatment for cells.


ggplate documentation built on Sept. 1, 2026, 5:07 p.m.