data_discrete_6: Discrete 6-well plate dataset

data_discrete_6R Documentation

Discrete 6-well plate dataset

Description

A dataset containing 3 conditions for a drug treatment in a 6-well plate. The treatment consists of a DMSO negative control, Rapamycin and Taxol. Each treatment is assigned to a position in a 6-well plate. The Control column marks the wells that contain the vehicle control.

Usage

data_discrete_6

Format

A data frame with a Condition, a well and a Control column.

Theoretically possible treatment for cells.


ggplate documentation built on Sept. 1, 2026, 5:07 p.m.