Skip to contents

A colour scheme for the borders of wells that contains 4 colours. The colours are meant to mark the status of a well (Fail, Check, OK and Not tested). They do not appear in the protti_colours and viridis_colours schemes, which ensures that borders are visible on every fill colour.

Usage

border_colours

Format

A vector containing 4 colours