| border_colours | R Documentation |
A colour scheme for the borders of wells that contains 4 colours. The colours are meant to
mark the status of a well (Fail, Check, OK and Not tested). They do not appear in the
protti_colours and viridis_colours schemes, which ensures that borders are visible on
every fill colour.
border_colours
A vector containing 4 colours
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.