A dataset containing 1536 positive numeric values randomly generated using a normal distribution (rnorm()).
Each value is assigned to a position in a 1536-well plate. The row format uses the A-AF labeling.
The Status column marks the wells at the edge of the plate, which are prone to evaporation.