data_continuous_1536_Aa: Continuous 1536-well plate dataset (Aa-Hd)

data_continuous_1536_AaR Documentation

Continuous 1536-well plate dataset (Aa-Hd)

Description

A dataset containing 1536 positive numeric values randomly generated using a normal distribution (rnorm()). Each value is assigned to a position in a 1536-well plate. The row format uses the Ab-Hd labeling.

Usage

data_continuous_1536_Aa

Format

A data frame with a Value and a well column.

Randomly generated.


ggplate documentation built on May 11, 2026, 9:06 a.m.