A dataset containing 384 positive numeric values randomly generated using a normal distribution (rnorm()).
Each value is assigned to a position in a 384-well plate.
The Status column marks the wells at the edge of the plate, which are prone to evaporation.