Skip to contents

A dataset containing 48 positive numeric values randomly generated using a normal distribution (rnorm()). Each value is assigned to a position in a 48-well plate. The Status column marks wells with a low or a high signal.

Usage

data_continuous_48

Format

A data frame with a Value, a well and a Status column.

Randomly generated.