A dataset containing 48 positive numeric values randomly generated using a normal distribution (rnorm()).
Each value is assigned to a position in a 48-well plate.
The Status column marks wells with a low or a high signal.
A dataset containing 48 positive numeric values randomly generated using a normal distribution (rnorm()).
Each value is assigned to a position in a 48-well plate.
The Status column marks wells with a low or a high signal.