Skip to contents

A dataset containing 23 positive numeric values randomly generated using a normal distribution (rnorm()). Each value is assigned to a position in a 48-well plate. Therefore, not every well in the plate contains a value. The position 1D and the second half of the plate are NA. The Status column marks the wells that were not tested. These wells are only shown if the remove_na argument of plate_plot() is set to FALSE.

Usage

data_continuous_48_incomplete

Format

A data frame with a Value, a well and a Status column.

Randomly generated.