Learn R Programming

ggplate (version 0.1.5)

data_discrete_24: Discrete 24-well plate dataset

Description

A dataset containing 12 conditions for an siRNA treatment in a 24-well plate. The siRNA treatment consists of a control (siControl) and 11 siRNAs targeting mRNAs of proteins in the mTORC1 pathway. Each treatment is assigned to a position in a 24-well plate.

Usage

data_discrete_24

Arguments

Format

A data frame with a Value and a well column.