Learn R Programming

ggplate (version 0.1.5)

data_discrete_6: Discrete 6-well plate dataset

Description

A dataset containing 3 conditions for a drug treatment in a 6-well plate. The treatment consists of a DMSO negative control, Rapamycin and Taxol. Each treatment is assigned to a position in a 6-well plate.

Usage

data_discrete_6

Arguments

Format

A data frame with a Value and a well column.