Learn R Programming

ggplate (version 0.1.5)

data_discrete_96: Discrete 96-well plate dataset

Description

A dataset containing 22 conditions for a hypothetical drug treatment in a 96-well plate. The first column contains the negative control while the last column contains the positive control. Each treatment is assigned to four wells in a 96-well plate.

Usage

data_discrete_96

Arguments

Format

A data frame with a Value and a well column.